<?php
/**
 * manufacturers list sidebox - displays a list of manufacturers so customer can choose to filter on their products only
 * Version 2 modified to allow display of a simple list of links in place of a scrolling list
 * Version 3 modified to allow those links to be manufacturers images
 * Version 4 allows the display of product counts next to manufacturers names' and puts files into directory hierarchy
 *
 * @package templateSystem
 * @copyright Copyright 2007-2009 Kuroi Web Design
 * @copyright Portions Copyright 2003-2006 Zen Cart Development Team
 * @copyright Portions Copyright 2003 osCommerce
 * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 * @version $Id: manufacturers.php 2009-07-29 kuroi $
 */

// Set to true to display manufacturers images in place of names
define('DISPLAY_MANUFACTURERS_IMAGES', false);

// set to true to display a count of the number of products for each manufacturer
define('DISPLAY_MANUFACTURERS_COUNTS', false);

// debug switch
define('DEBUG_MANUFACTURERS_SIDEBOX', false);

// test if manufacturers sidebox should show
$show_manufacturers = true;

if (DEBUG_MANUFACTURERS_SIDEBOX) {
  echo "Entering manufacturers module ...<br/>\n";
  echo '- Images: ' . (DISPLAY_MANUFACTURERS_IMAGES ? 'TRUE' : 'FALSE') . "<br/>\n";
  echo '- Man. Status: ' . PRODUCTS_MANUFACTURERS_STATUS . "<br/>\n";
  echo '- Counts: ' . (DISPLAY_MANUFACTURERS_COUNTS ? 'TRUE' : 'FALSE') . "<br/>\n";
  echo '- Show: ' . ($show_manufacturers ? 'TRUE' : 'FALSE') . "<br/><br/>\n";
}

if ($show_manufacturers) {

  if (PRODUCTS_MANUFACTURERS_STATUS == '1' || DISPLAY_MANUFACTURERS_COUNTS) {
    // pull counts from the database
    $manufacturer_counts_query = "SELECT manufacturers_id, COUNT(products_id) AS number
                                  FROM " . TABLE_PRODUCTS . "
                                  WHERE products_status = 1 AND manufacturers_id IS NOT NULL AND manufacturers_id > 0
                                  GROUP BY manufacturers_id";
    $manufacturer_counts_result = $db->Execute($manufacturer_counts_query);

    // prepare counts for use later
    $manufacturer_counts_list = array();
    while (!$manufacturer_counts_result->EOF) {
      $manufacturer_counts_list[$manufacturer_counts_result->fields['manufacturers_id']] = $manufacturer_counts_result->fields['number'];
	  $manufacturer_counts_result->MoveNext();
	}
	
	if (DEBUG_MANUFACTURERS_SIDEBOX) {
	  echo '<h4>List of Counts</h4>';
      echo '<pre>' . "\n";
	  var_dump($manufacturer_counts_list);
	  echo '</pre>' . "\n";
    }
	
  }

  // now let's get the manufacturers
  $manufacturer_sidebox_query = "SELECT manufacturers_id, manufacturers_name, manufacturers_image
                                 FROM " . TABLE_MANUFACTURERS . "
                                 ORDER BY manufacturers_name";
  $manufacturer_sidebox_result = $db->Execute($manufacturer_sidebox_query);

  if ($manufacturer_sidebox_result->RecordCount() > 0) {

    $manufacturer_sidebox_list = array();

    while (!$manufacturer_sidebox_result->EOF) {

	// prepare data
	  $manufacturer_id = $manufacturer_sidebox_result->fields['manufacturers_id'];
      $manufacturer_name = ((strlen($manufacturer_sidebox_result->fields['manufacturers_name']) > MAX_DISPLAY_MANUFACTURER_NAME_LEN) ? substr($manufacturer_sidebox_result->fields['manufacturers_name'], 0, MAX_DISPLAY_MANUFACTURER_NAME_LEN) . '..' : $manufacturer_sidebox_result->fields['manufacturers_name']);
	  $manufacturer_image = $manufacturer_sidebox_result->fields['manufacturers_image'];
      $manufacturer_count = isset($manufacturer_counts_list[$manufacturer_id]) ? (int)$manufacturer_counts_list[$manufacturer_id] : 0;

	if (DEBUG_MANUFACTURERS_SIDEBOX) {
      echo 'Processing ' . $manufacturer_name . "<br/>\n";
    }
	  
      // add to sidebox list only if we are showing all manufacturers, or this one has products
	  if (PRODUCTS_MANUFACTURERS_STATUS != '1' || $manufacturer_count > 0) {
        $manufacturer_sidebox_list[] = array(
          'id' => $manufacturer_id,
          'text' => DISPLAY_MANUFACTURERS_IMAGES ? zen_image(DIR_WS_IMAGES . $manufacturer_image, $manufacturer_name) : $manufacturer_name,
          'count' => $manufacturer_count);
      }

      // advance to next result
	  $manufacturer_sidebox_result->MoveNext();
    }

	if (DEBUG_MANUFACTURERS_SIDEBOX) {
      echo '<br/><h4>Final Sidebox List</h4>';
      echo '<pre>' . "\n";
	  var_dump($manufacturer_sidebox_list);
	  echo '</pre>' . "\n";
    }
	
	if (sizeof($manufacturer_sidebox_list) > 0 ) {
      require($template->get_template_dir('tpl_manufacturers_list.php',DIR_WS_TEMPLATE, $current_page_base,'sideboxes'). '/tpl_manufacturers_list.php');
      $title = BOX_HEADING_MANUFACTURERS;
      $title_link = false;
      require($template->get_template_dir($column_box_default, DIR_WS_TEMPLATE, $current_page_base,'common') . '/' . $column_box_default);
    }
  }
}